@@ -1,4 +1,4 @@
-# Copyright 2020-2021 Leibniz Information Centre for Economics
+# Copyright 2020-2023 Leibniz Information Centre for Economics
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,14 +16,19 @@
 from typing import Tuple, FrozenSet, Iterable, Any, Optional
 from rdflib import Graph
 from rdflib.term import Literal, URIRef
-from rdflib.namespace import SKOS, OWL, RDF
+from rdflib.namespace import Namespace, SKOS, OWL, RDF
+
+ZBWEXT = Namespace("http://zbw.eu/namespaces/zbw-extensions/")
 
 
 def extract_labels(g: Graph) -> Iterable[Tuple[URIRef, Literal]]:
     """
-    Extracts SKOS.prefLabels and SKOS.altLabels from a rdflib.Graph
+    Extracts SKOS.prefLabels, SKOS.altLabels, SKOS.hiddenLabel,
+    ZBWEXT.altLabelRelated and ZBWEXT.altLabelNarrower from a rdflib.Graph
     """
-    return g[: SKOS.prefLabel | SKOS.altLabel]
+    # return g[: SKOS.prefLabel | SKOS.altLabel]
+    return g[: SKOS.prefLabel | SKOS.altLabel | SKOS.hiddenLabel |
+             ZBWEXT.altLabelRelated | ZBWEXT.altLabelNarrower]
 
 
 def extract_by_type_uri(
@@ -106,29 +111,30 @@ def retrieve_concept_labels(
         allowed: Optional[FrozenSet[URIRef]] = frozenset(),
         langs: FrozenSet[str] = frozenset()
         ) -> Iterable[Tuple[URIRef, str]]:
-    """Extracts altLabels and prefLabels from a SKOS graph.
+    """Extracts altLabels, altLabelNarrower,
+    altLabelRelated and prefLabels from a SKOS graph.
 
     Only the labels that are in one of the specified language will be reported.
     In addition the concept URIs can be limited by a set.
-    Args:
-        g: The SKOS graph whose labels are extracted.
 
-        allowed: Only concepts present in the set are retained.
+    :param g: The SKOS graph whose labels are extracted.
+
+    :param allowed: Only concepts present in the set are retained.
             If None or the set is empty
             all concepts will be present in the result.
 
 
-        langs: Only retain labels that are in the given language.
+    :param  langs: Only retain labels that are in the given language.
             Add None to the set if you want to keep labels
             without a language annotation.
 
 
-    Returns:
+    :return:
         An iterator of pairs. The first element is a URIRef,
         representing a concept.
         The second element is a label for the concept.
 
-        """
+    """
     refs_with_labels = extract_labels(g)
     if langs is not None and len(langs) > 0:
         filtered_by_language = _filter_by_langs(refs_with_labels, langs)
